@@ -18,6 +18,9 @@ from datetime import datetime
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
 
+# Global variable to control logging
+ENABLE_LOGGING = False
+
 # Global variables for host control and serial configuration
 ALLOWED_HOSTS = {}
 LOG_FILE = "requests.log"
@@ -108,8 +111,12 @@ def is_host_allowed(client_ip, port):
 
 def log_request(client_ip, client_port, method, path, status, response_size=0, user_agent="", response_data=None):
     """
-    Log request to requests.log file with response data
+    Log request to requests.log file with response data (only if logging is enabled)
     """
+    # Only log if logging is enabled
+    if not ENABLE_LOGGING:
+        return
+        
     timestamp = datetime.now().strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
     
     # Basic log entry
@@ -348,61 +355,32 @@ class SerialServerHandler(http.server.BaseHTTPRequestHandler):
     
     def do_POST(self):
         """
-        Handle POST requests
+        Handle POST requests - Not supported, only GET is allowed
         """
-        # Check access first
-        if not self.check_access():
-            self.send_response(403)
-            self.send_header('Content-type', 'text/plain')
-            self.end_headers()
-            self.wfile.write(b'Access Denied')
-            return
+        logger.info(f"POST request from {self.client_address[0]}:{self.client_address[1]} - Method not allowed")
         
-        logger.info(f"POST request from {self.client_address[0]}:{self.client_address[1]}")
-        
-        # Get content length
-        content_length = int(self.headers.get('Content-Length', 0))
-        
-        # Read request body
-        post_data = ""
-        if content_length > 0:
-            post_data = self.rfile.read(content_length).decode('utf-8')
-            logger.info(f"POST data: {post_data}")
-        
-        # Get response data based on mode
-        if TEST_MODE:
-            message_data = get_test_response()
-        else:
-            message_data = get_serial_response()
-        
-        # Prepare response data
-        response_data = {
-            'message': message_data,
-            'timestamp': datetime.now().isoformat(),
-            'method': 'POST',
-            'path': self.path,
-            'client_ip': self.client_address[0],
-            'client_port': self.client_address[1],
-            'received_data': post_data
-        }
-        
-        # Send response
-        self.send_response(200)
+        # Send 405 Method Not Allowed response
+        self.send_response(405)
         self.send_header('Content-type', 'application/json')
-        self.send_header('Access-Control-Allow-Origin', '*')
-        self.send_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
-        self.send_header('Access-Control-Allow-Headers', 'Content-Type')
+        self.send_header('Allow', 'GET')
         self.end_headers()
         
-        # Send JSON response
-        response_json = json.dumps(response_data, indent=2)
+        # Send error response
+        error_response = {
+            'error': 'Method Not Allowed',
+            'message': 'Only GET method is supported',
+            'allowed_methods': ['GET'],
+            'timestamp': datetime.now().isoformat()
+        }
+        
+        response_json = json.dumps(error_response, indent=2)
         response_bytes = response_json.encode('utf-8')
         self.wfile.write(response_bytes)
         
-        # Log successful response with response data
-        log_request(self.client_address[0], self.client_address[1], 'POST', self.path, 'ACCEPTED', len(response_bytes), self.headers.get('User-Agent', ''), response_data)
+        # Log request
+        log_request(self.client_address[0], self.client_address[1], 'POST', self.path, 'REJECTED', len(response_bytes), self.headers.get('User-Agent', ''), error_response)
         
-        logger.info("Response sent successfully")
+        logger.info("POST method rejected - only GET is allowed")
     
     def do_OPTIONS(self):
         """
@@ -420,7 +398,7 @@ class SerialServerHandler(http.server.BaseHTTPRequestHandler):
         
         self.send_response(200)
         self.send_header('Access-Control-Allow-Origin', '*')
-        self.send_header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS')
+        self.send_header('Access-Control-Allow-Methods', 'GET, OPTIONS')
         self.send_header('Access-Control-Allow-Headers', 'Content-Type')
         self.end_headers()
         
@@ -582,7 +560,9 @@ def start_server(port=7373, host='localhost'):
             logger.info(f"  GET  http://{host}:{port}/")
 #            logger.info(f"  POST http://{host}:{port}/")
             logger.info(f"Host access control: {'ENABLED' if ALLOWED_HOSTS else 'DISABLED'}")
-            logger.info(f"Log file: {LOG_FILE}")
+            logger.info(f"Logging: {'ENABLED' if ENABLE_LOGGING else 'DISABLED'}")
+            if ENABLE_LOGGING:
+                logger.info(f"Log file: {LOG_FILE}")
             logger.info(f"Mode: {'TEST' if TEST_MODE else 'SERIAL'}")
             if not TEST_MODE and SERIAL_CONFIG:
                 logger.info(f"Serial port: {SERIAL_CONFIG.get('port', 'Not configured')}")
@@ -625,9 +605,14 @@ def main():
     parser.add_argument('--test', action='store_true', help='Run in test mode (returns test data instead of reading serial port)')
     parser.add_argument('--abap', action='store_true', help='Copy ABAP files to current directory and exit')
     parser.add_argument('--init', action='store_true', help='Initialize serialsrv.json configuration file and exit')
+    parser.add_argument('--log', action='store_true', help='Enable logging to requests.log file')
     
     args = parser.parse_args()
     
+    # Set global logging flag
+    global ENABLE_LOGGING
+    ENABLE_LOGGING = args.log
+    
     # Handle configuration file initialization
     if args.init:
         print("🔧 SerialSrv - Configuration Initializer")
